/* ====================================================================
 * Copyright (c) 2009       Martin Hauner
 *                          http://subcommander.tigris.org
 *
 * Subcommander is licensed as described in the file doc/COPYING, which
 * you should have received as part of this distribution.
 * ====================================================================
 */

#ifndef _SIGNAL_TARGET_H
#define _SIGNAL_TARGET_H

// qt
#include <QtCore/QObject>
class QModelIndex;

class SignalTarget : public QObject
{
  Q_OBJECT;

public:
  SignalTarget( QObject* src );
  ~SignalTarget();

public slots:
  virtual void modelAboutToBeReset() {}
  virtual void modelReset() {}
  virtual void layoutAboutToBeChanged() {}
  virtual void layoutChanged() {}
  virtual void rowsAboutToBeInserted(const QModelIndex& srcParent, int start, int end) {}
  virtual void rowsInserted(const QModelIndex& srcParent, int start, int end) {}

private:
  QObject* _src;
};


#endif // _SIGNAL_TARGET_H
